# smartsheet-helper
Simple class that helps dealing with smarsheet api, like dealing with columin ids and types

it uses environment variables for keys and ids:

SMARTSHEET_SHEET_ID=your_sheet_id
SMARTSHEET_ACCESS_TOKEN=your_secret_access_token
